# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/game/slott/game/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/game/slott/game/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Game\\Slott/game\\": "packages/game/slott/game/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Game\Slott/game\Providers\Slott/gameServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Slott/game'  => Game\Slott/game\Facades\Slott/game::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Game\\Slott/gameTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Game\Slott/game\Providers\Slott/gameServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Game\Slott/game\Providers\Slott/gameServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Game\Slott/game\Providers\Slott/gameServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/slott/game/{modulename}

**User**

    http://path-to-route-folder/user/slott/game/{modulename}

**Public**

    http://path-to-route-folder/slott/games


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/slott/game/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/slott/game/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/slott/game/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/slott/game/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/slott/game/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/slott/game/{modulename}/{slug}
    METHOD: GET